# volvox

Placeholder package to reserve the PyPI name **volvox**.

If you are looking for the deep learning framework that will use this name, please check the project repository once it is published.
